@@ -7,33 +7,14 @@
  */
 
 #include "bluezqtextensionplugin.h"
-#include "declarativeadapter.h"
-#include "declarativebattery.h"
-#include "declarativedevice.h"
-#include "declarativedevicesmodel.h"
-#include "declarativeinput.h"
-#include "declarativemanager.h"
-#include "declarativemediaplayer.h"
-#include "device.h"
-#include "pendingcall.h"
-#include "rfkill.h"
 #include "services.h"
 
-#include <QQmlEngine>
-
-static QObject *manager_singleton(QQmlEngine *engine, QJSEngine *scriptEngine)
-{
-    Q_UNUSED(engine)
-    Q_UNUSED(scriptEngine)
-
-    return new DeclarativeManager;
-}
-
 static QJSValue services_singleton(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
     Q_UNUSED(engine)
 
     QJSValue object = scriptEngine->newObject();
+
     object.setProperty(QStringLiteral("ServiceDiscoveryServer"), BluezQt::Services::ServiceDiscoveryServer);
     object.setProperty(QStringLiteral("SerialPort"), BluezQt::Services::SerialPort);
     object.setProperty(QStringLiteral("DialupNetworking"), BluezQt::Services::DialupNetworking);
@@ -55,13 +36,21 @@ static QJSValue services_singleton(QQmlEngine *engine, QJSEngine *scriptEngine)
     object.setProperty(QStringLiteral("PhonebookAccessServer"), BluezQt::Services::PhonebookAccessServer);
     object.setProperty(QStringLiteral("MessageAccessServer"), BluezQt::Services::MessageAccessServer);
     object.setProperty(QStringLiteral("PnpInformation"), BluezQt::Services::PnpInformation);
+
+    // Bluetooth Low Energy
     object.setProperty(QStringLiteral("GenericAccess"), BluezQt::Services::GenericAccess);
-    object.setProperty(QStringLiteral("GenericAcces"), BluezQt::Services::GenericAccess); // TODO KF6: Remove the one with typo
+    object.setProperty(QStringLiteral("GenericAcces"), BluezQt::Services::GenericAccess); // TODO KF7: Remove the one with typo
     object.setProperty(QStringLiteral("GenericAttribute"), BluezQt::Services::GenericAttribute);
     object.setProperty(QStringLiteral("ImmediateAlert"), BluezQt::Services::ImmediateAlert);
     object.setProperty(QStringLiteral("LinkLoss"), BluezQt::Services::LinkLoss);
     object.setProperty(QStringLiteral("TxPower"), BluezQt::Services::TxPower);
     object.setProperty(QStringLiteral("HeartRate"), BluezQt::Services::HeartRate);
+    object.setProperty(QStringLiteral("CoordinatedSetIdentification"), BluezQt::Services::CoordinatedSetIdentification);
+    object.setProperty(QStringLiteral("MicrophoneControl"), BluezQt::Services::MicrophoneControl);
+    object.setProperty(QStringLiteral("BroadcastAudioScan"), BluezQt::Services::BroadcastAudioScan);
+    object.setProperty(QStringLiteral("PublishedAudioCapabilities"), BluezQt::Services::PublishedAudioCapabilities);
+    object.setProperty(QStringLiteral("CommonAudio"), BluezQt::Services::CommonAudio);
+
     return object;
 }
 
@@ -71,14 +60,7 @@ void BluezQtExtensionPlugin::registerTypes(const char *uri)
 
     Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.bluezqt"));
 
-    qmlRegisterSingletonType<DeclarativeManager>(uri, 1, 0, "Manager", manager_singleton);
-    qmlRegisterType<DeclarativeDevicesModel>(uri, 1, 0, "DevicesModelPrivate");
-    qmlRegisterUncreatableType<DeclarativeAdapter>(uri, 1, 0, "Adapter", QStringLiteral("Adapter cannot be created"));
-    qmlRegisterUncreatableType<DeclarativeBattery>(uri, 1, 0, "Battery", QStringLiteral("Battery cannot be created"));
-    qmlRegisterUncreatableType<DeclarativeDevice>(uri, 1, 0, "Device", QStringLiteral("Device cannot be created"));
-    qmlRegisterUncreatableType<DeclarativeInput>(uri, 1, 0, "Input", QStringLiteral("Input cannot be created"));
-    qmlRegisterUncreatableType<DeclarativeMediaPlayer>(uri, 1, 0, "MediaPlayer", QStringLiteral("MediaPlayer cannot be created"));
-    qmlRegisterUncreatableType<PendingCall>(uri, 1, 0, "PendingCall", QStringLiteral("PendingCall cannot be created"));
-    qmlRegisterUncreatableType<Rfkill>(uri, 1, 0, "Rfkill", QStringLiteral("Rfkill cannot be created"));
     qmlRegisterSingletonType(uri, 1, 0, "Services", services_singleton);
 }
+
+#include "moc_bluezqtextensionplugin.cpp"
