@@ -59,10 +59,7 @@ Input::Input(const QString &path, const QVariantMap &properties)
 {
 }
 
-Input::~Input()
-{
-    delete d;
-}
+Input::~Input() = default;
 
 InputPtr Input::toSharedPtr() const
 {
@@ -75,3 +72,6 @@ Input::ReconnectMode Input::reconnectMode() const
 }
 
 } // namespace BluezQt
+
+#include "moc_input.cpp"
+#include "moc_input_p.cpp"
